# Criteo API SDK for Python

## Introduction
API Client Libraries can facilitate your use of the Criteo API allowing you to build unique and customized solutions to serve your businesses and clients.
These libraries can reduce the amount of code you need to write in order to start accessing Criteo programmatically. They also can help expedite troubleshooting, should you encounter any issues.

More information on how to use Criteo API and these SDKs can be found at: [https://developers.criteo.com/](https://developers.criteo.com/).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- Package version: 2025.04.0.250606

## Requirements

Python 2.7 and 3.5+

## Installation & Usage
### pip install

```sh
pip install criteo-api-retailmedia-sdk==2025.04.0.250606
```
(you may need to run `pip` with root permission: `sudo pip install criteo-api-retailmedia-sdk==2025.04.0.250606`)

Then import the package:
```python
import criteo_api_retailmedia_v2025_04
```

### Manual Installation using [Setuptools](http://pypi.python.org/pypi/setuptools)

Download the code or clone the repository locally, then execute the following command:

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import criteo_api_retailmedia_v2025_04
```

## Example
There are multiple examples for the different OAuth flows that the SDK supports.
- See [test/example_application_with_client_credentials.py](test/example_application_with_client_credentials.py) for an example with Client Credentials.
- See [test/example_application_with_auth_code.py](test/example_application_with_auth_code.py) for an example with Authorization Code.
Once you follow the authorization code flow, you will have a refresh token that has to be used to regenerate access token for future usage. 
    - See [test/example_application_with_refresh_token.py](test/example_application_with_refresh_token.py) for an example with Refresh Token .

## Documentation for API Endpoints

The developers documentation is available at: *https://developers.criteo.com*.

All URIs are relative to *https://api.criteo.com*.

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**add_brands**](docs/AccountsApi.md#add_brands) | **POST** /2025-04/retail-media/account-management/accounts/{accountId}/brands/add | 
*AccountsApi* | [**create_private_market_demand_brand_account**](docs/AccountsApi.md#create_private_market_demand_brand_account) | **POST** /2025-04/retail-media/account-management/accounts/{accountId}/create-brand-account | 
*AccountsApi* | [**create_private_market_demand_seller_account**](docs/AccountsApi.md#create_private_market_demand_seller_account) | **POST** /2025-04/retail-media/account-management/accounts/{accountId}/create-seller-account | 
*AccountsApi* | [**get_api_external_v1_account_private_market_child_accounts_by_account_id**](docs/AccountsApi.md#get_api_external_v1_account_private_market_child_accounts_by_account_id) | **GET** /2025-04/retail-media/account-management/accounts/{accountId}/private-market-child-accounts | 
*AccountsApi* | [**get_api_v1_external_accounts**](docs/AccountsApi.md#get_api_v1_external_accounts) | **GET** /2025-04/retail-media/accounts | 
*AccountsApi* | [**grant_consent**](docs/AccountsApi.md#grant_consent) | **POST** /2025-04/retail-media/accounts/{accountId}/grant-consent | 
*AccountsApi* | [**remove_brands**](docs/AccountsApi.md#remove_brands) | **POST** /2025-04/retail-media/account-management/accounts/{accountId}/brands/remove | 
*AccountsApi* | [**search_sellers**](docs/AccountsApi.md#search_sellers) | **POST** /2025-04/retail-media/accounts/sellers/search | 
*AccountsApi* | [**update_sellers**](docs/AccountsApi.md#update_sellers) | **PUT** /2025-04/retail-media/account-management/accounts/{accountId}/sellers | 
*AnalyticsApi* | [**generate_async_campaigns_report**](docs/AnalyticsApi.md#generate_async_campaigns_report) | **POST** /2025-04/retail-media/reports/campaigns | 
*AnalyticsApi* | [**generate_async_line_items_report**](docs/AnalyticsApi.md#generate_async_line_items_report) | **POST** /2025-04/retail-media/reports/line-items | 
*AnalyticsApi* | [**generate_async_revenue_report**](docs/AnalyticsApi.md#generate_async_revenue_report) | **POST** /2025-04/retail-media/reports/revenue | 
*AnalyticsApi* | [**get_async_export_output**](docs/AnalyticsApi.md#get_async_export_output) | **GET** /2025-04/retail-media/reports/{reportId}/output | 
*AnalyticsApi* | [**get_async_export_status**](docs/AnalyticsApi.md#get_async_export_status) | **GET** /2025-04/retail-media/reports/{reportId}/status | 
*AudienceApi* | [**bulk_create_audience_segments**](docs/AudienceApi.md#bulk_create_audience_segments) | **POST** /2025-04/retail-media/accounts/{account-id}/audience-segments/create | 
*AudienceApi* | [**bulk_delete_audience_segments**](docs/AudienceApi.md#bulk_delete_audience_segments) | **POST** /2025-04/retail-media/accounts/{account-id}/audience-segments/delete | 
*AudienceApi* | [**bulk_update_audience_segments**](docs/AudienceApi.md#bulk_update_audience_segments) | **PATCH** /2025-04/retail-media/accounts/{account-id}/audience-segments | 
*AudienceApi* | [**delete_contact_list_identifiers**](docs/AudienceApi.md#delete_contact_list_identifiers) | **POST** /2025-04/retail-media/audience-segments/{audience-segment-id}/contact-list/clear | 
*AudienceApi* | [**get_audience_segment_contact_list_statistics**](docs/AudienceApi.md#get_audience_segment_contact_list_statistics) | **GET** /2025-04/retail-media/accounts/{account-id}/audience-segments/{audience-segment-id}/contact-list | 
*AudienceApi* | [**search_audience_segments**](docs/AudienceApi.md#search_audience_segments) | **POST** /2025-04/retail-media/accounts/{account-id}/audience-segments/search | 
*AudienceApi* | [**search_audiences**](docs/AudienceApi.md#search_audiences) | **POST** /2025-04/retail-media/accounts/{account-id}/audiences/search | 
*AudienceApi* | [**update_contact_list_identifiers**](docs/AudienceApi.md#update_contact_list_identifiers) | **POST** /2025-04/retail-media/audience-segments/{audience-segment-id}/contact-list/add-remove | 
*BalanceApi* | [**get_api202110_external_balance_campaigns_by_balance_id**](docs/BalanceApi.md#get_api202110_external_balance_campaigns_by_balance_id) | **GET** /2025-04/retail-media/balances/{balance-id}/campaigns | 
*BalanceApi* | [**get_api_v2_external_account_balances_by_account_id**](docs/BalanceApi.md#get_api_v2_external_account_balances_by_account_id) | **GET** /2025-04/retail-media/accounts/{account-id}/balances | 
*BalanceApi* | [**get_api_v2_external_account_by_account_id_balancesbalance_id**](docs/BalanceApi.md#get_api_v2_external_account_by_account_id_balancesbalance_id) | **GET** /2025-04/retail-media/accounts/{account-id}/balances/{balance-id} | 
*BalanceApi* | [**get_balance_history**](docs/BalanceApi.md#get_balance_history) | **GET** /2025-04/retail-media/balances/{balanceId}/history | 
*BalanceApi* | [**patch_api_v2_external_account_by_account_id_balancesbalance_id**](docs/BalanceApi.md#patch_api_v2_external_account_by_account_id_balancesbalance_id) | **PATCH** /2025-04/retail-media/accounts/{account-id}/balances/{balance-id} | 
*BalanceApi* | [**post_api_v2_external_account_add_funds_by_account_id_balancesbalance_id**](docs/BalanceApi.md#post_api_v2_external_account_add_funds_by_account_id_balancesbalance_id) | **POST** /2025-04/retail-media/accounts/{account-id}/balances/{balance-id}/add-funds | 
*BalanceApi* | [**post_api_v2_external_account_balances_by_account_id**](docs/BalanceApi.md#post_api_v2_external_account_balances_by_account_id) | **POST** /2025-04/retail-media/accounts/{account-id}/balances | 
*BalanceApi* | [**post_api_v2_external_account_change_dates_by_account_id_balancesbalance_id**](docs/BalanceApi.md#post_api_v2_external_account_change_dates_by_account_id_balancesbalance_id) | **POST** /2025-04/retail-media/accounts/{account-id}/balances/{balance-id}/change-dates | 
*CampaignApi* | [**add_remove_keywords**](docs/CampaignApi.md#add_remove_keywords) | **POST** /2025-04/retail-media/line-items/{id}/keywords/add-remove | 
*CampaignApi* | [**append_promoted_products**](docs/CampaignApi.md#append_promoted_products) | **POST** /2025-04/retail-media/line-items/{line-item-id}/products/append | 
*CampaignApi* | [**create_asset**](docs/CampaignApi.md#create_asset) | **POST** /2025-04/retail-media/assets | 
*CampaignApi* | [**delete_promoted_products**](docs/CampaignApi.md#delete_promoted_products) | **POST** /2025-04/retail-media/line-items/{line-item-id}/products/delete | 
*CampaignApi* | [**fetch_keywords**](docs/CampaignApi.md#fetch_keywords) | **GET** /2025-04/retail-media/line-items/{id}/keywords | 
*CampaignApi* | [**fetch_promoted_products**](docs/CampaignApi.md#fetch_promoted_products) | **GET** /2025-04/retail-media/line-items/{line-item-id}/products | 
*CampaignApi* | [**get_api202110_external_account_creatives_by_account_id**](docs/CampaignApi.md#get_api202110_external_account_creatives_by_account_id) | **GET** /2025-04/retail-media/accounts/{account-id}/creatives | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id) | **GET** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id) | **GET** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_targeting_stores_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_targeting_stores_by_line_item_id) | **GET** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores | 
*CampaignApi* | [**get_api202110_external_retailer_pages_by_retailer_id**](docs/CampaignApi.md#get_api202110_external_retailer_pages_by_retailer_id) | **GET** /2025-04/retail-media/retailers/{retailerId}/pages | 
*CampaignApi* | [**get_api202204_external_categorie_by_category_id**](docs/CampaignApi.md#get_api202204_external_categorie_by_category_id) | **GET** /2025-04/retail-media/categories/{categoryId} | 
*CampaignApi* | [**get_api202204_external_categories**](docs/CampaignApi.md#get_api202204_external_categories) | **GET** /2025-04/retail-media/categories | 
*CampaignApi* | [**get_api202207_external_retailer_by_retailer_id_templatestemplate_id**](docs/CampaignApi.md#get_api202207_external_retailer_by_retailer_id_templatestemplate_id) | **GET** /2025-04/retail-media/retailers/{retailer-id}/templates/{template-id} | 
*CampaignApi* | [**get_api202207_external_retailer_templates_by_retailer_id**](docs/CampaignApi.md#get_api202207_external_retailer_templates_by_retailer_id) | **GET** /2025-04/retail-media/retailers/{retailer-id}/templates | 
*CampaignApi* | [**get_api202301_external_account_campaigns_by_account_id**](docs/CampaignApi.md#get_api202301_external_account_campaigns_by_account_id) | **GET** /2025-04/retail-media/accounts/{account-id}/campaigns | 
*CampaignApi* | [**get_api202301_external_campaign_by_campaign_id**](docs/CampaignApi.md#get_api202301_external_campaign_by_campaign_id) | **GET** /2025-04/retail-media/campaigns/{campaignId} | 
*CampaignApi* | [**get_api_v1_external_account_brands_by_account_id**](docs/CampaignApi.md#get_api_v1_external_account_brands_by_account_id) | **GET** /2025-04/retail-media/accounts/{accountId}/brands | 
*CampaignApi* | [**get_api_v1_external_account_retailers_by_account_id**](docs/CampaignApi.md#get_api_v1_external_account_retailers_by_account_id) | **GET** /2025-04/retail-media/accounts/{accountId}/retailers | 
*CampaignApi* | [**get_api_v1_external_catalog_output_by_catalog_id**](docs/CampaignApi.md#get_api_v1_external_catalog_output_by_catalog_id) | **GET** /2025-04/retail-media/catalogs/{catalogId}/output | 
*CampaignApi* | [**get_api_v1_external_catalog_status_by_catalog_id**](docs/CampaignApi.md#get_api_v1_external_catalog_status_by_catalog_id) | **GET** /2025-04/retail-media/catalogs/{catalogId}/status | 
*CampaignApi* | [**get_api_v2_external_account_by_account_id_creativescreative_id**](docs/CampaignApi.md#get_api_v2_external_account_by_account_id_creativescreative_id) | **GET** /2025-04/retail-media/accounts/{account-id}/creatives/{creative-id} | 
*CampaignApi* | [**get_api_v2_external_account_line_items_by_account_id**](docs/CampaignApi.md#get_api_v2_external_account_line_items_by_account_id) | **GET** /2025-04/retail-media/accounts/{account-id}/line-items | 
*CampaignApi* | [**get_api_v2_external_auction_line_item_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_auction_line_item_by_line_item_id) | **GET** /2025-04/retail-media/auction-line-items/{line-item-id} | 
*CampaignApi* | [**get_api_v2_external_campaign_auction_line_items_by_campaign_id**](docs/CampaignApi.md#get_api_v2_external_campaign_auction_line_items_by_campaign_id) | **GET** /2025-04/retail-media/campaigns/{campaign-id}/auction-line-items | 
*CampaignApi* | [**get_api_v2_external_campaign_preferred_line_items_by_campaign_id**](docs/CampaignApi.md#get_api_v2_external_campaign_preferred_line_items_by_campaign_id) | **GET** /2025-04/retail-media/campaigns/{campaign-id}/preferred-line-items | 
*CampaignApi* | [**get_api_v2_external_line_item_bid_multipliers_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_line_item_bid_multipliers_by_line_item_id) | **GET** /2025-04/retail-media/line-items/{line-item-id}/bid-multipliers | 
*CampaignApi* | [**get_api_v2_external_line_item_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_line_item_by_line_item_id) | **GET** /2025-04/retail-media/line-items/{line-item-id} | 
*CampaignApi* | [**get_api_v2_external_preferred_line_item_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_preferred_line_item_by_line_item_id) | **GET** /2025-04/retail-media/preferred-line-items/{line-item-id} | 
*CampaignApi* | [**get_campaign_budget_overrides**](docs/CampaignApi.md#get_campaign_budget_overrides) | **GET** /2025-04/retail-media/campaigns/{campaignId}/campaign-budget-overrides | 
*CampaignApi* | [**get_cpc_min_bids_by_sku_ids_v1**](docs/CampaignApi.md#get_cpc_min_bids_by_sku_ids_v1) | **POST** /2025-04/retail-media/retailers/{retailerId}/cpc-min-bids | 
*CampaignApi* | [**get_line_item_budget_overrides**](docs/CampaignApi.md#get_line_item_budget_overrides) | **GET** /2025-04/retail-media/line-items/{lineItemId}/line-item-budget-overrides | 
*CampaignApi* | [**get_recommended_keywords**](docs/CampaignApi.md#get_recommended_keywords) | **GET** /2025-04/retail-media/line-items/{externalLineItemId}/keywords/recommended | 
*CampaignApi* | [**pause_promoted_products**](docs/CampaignApi.md#pause_promoted_products) | **POST** /2025-04/retail-media/line-items/{line-item-id}/products/pause | 
*CampaignApi* | [**post_api202110_external_balance_campaigns_append_by_balance_id**](docs/CampaignApi.md#post_api202110_external_balance_campaigns_append_by_balance_id) | **POST** /2025-04/retail-media/balances/{balance-id}/campaigns/append | 
*CampaignApi* | [**post_api202110_external_balance_campaigns_delete_by_balance_id**](docs/CampaignApi.md#post_api202110_external_balance_campaigns_delete_by_balance_id) | **POST** /2025-04/retail-media/balances/{balance-id}/campaigns/delete | 
*CampaignApi* | [**post_api202110_external_campaign_preferred_line_items_by_campaign_id**](docs/CampaignApi.md#post_api202110_external_campaign_preferred_line_items_by_campaign_id) | **POST** /2025-04/retail-media/campaigns/{campaign-id}/preferred-line-items | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_add_to_basket_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_add_to_basket_append_by_line_item_id) | **POST** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket/append | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_add_to_basket_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_add_to_basket_delete_by_line_item_id) | **POST** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket/delete | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_audiences_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_audiences_append_by_line_item_id) | **POST** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences/append | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_audiences_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_audiences_delete_by_line_item_id) | **POST** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences/delete | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_stores_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_stores_append_by_line_item_id) | **POST** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores/append | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_stores_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_stores_delete_by_line_item_id) | **POST** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores/delete | 
*CampaignApi* | [**post_api202210_external_account_creatives_by_account_id**](docs/CampaignApi.md#post_api202210_external_account_creatives_by_account_id) | **POST** /2025-04/retail-media/accounts/{account-id}/creatives | 
*CampaignApi* | [**post_api202301_external_account_campaigns_by_account_id**](docs/CampaignApi.md#post_api202301_external_account_campaigns_by_account_id) | **POST** /2025-04/retail-media/accounts/{account-id}/campaigns | 
*CampaignApi* | [**post_api_v1_external_account_catalogs_by_account_id**](docs/CampaignApi.md#post_api_v1_external_account_catalogs_by_account_id) | **POST** /2025-04/retail-media/accounts/{accountId}/catalogs | 
*CampaignApi* | [**post_api_v1_external_account_catalogs_sellers_by_account_id**](docs/CampaignApi.md#post_api_v1_external_account_catalogs_sellers_by_account_id) | **POST** /2025-04/retail-media/accounts/{accountId}/catalogs/sellers | 
*CampaignApi* | [**post_api_v2_external_account_creatives_search_by_account_id**](docs/CampaignApi.md#post_api_v2_external_account_creatives_search_by_account_id) | **POST** /2025-04/retail-media/accounts/{account-id}/creatives/search | 
*CampaignApi* | [**post_api_v2_external_campaign_auction_line_items_by_campaign_id**](docs/CampaignApi.md#post_api_v2_external_campaign_auction_line_items_by_campaign_id) | **POST** /2025-04/retail-media/campaigns/{campaign-id}/auction-line-items | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_by_line_item_id) | **PUT** /2025-04/retail-media/preferred-line-items/{line-item-id} | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id) | **PUT** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id) | **PUT** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_targeting_stores_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_targeting_stores_by_line_item_id) | **PUT** /2025-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores | 
*CampaignApi* | [**put_api202210_external_account_by_account_id_creativescreative_id**](docs/CampaignApi.md#put_api202210_external_account_by_account_id_creativescreative_id) | **PUT** /2025-04/retail-media/accounts/{account-id}/creatives/{creative-id} | 
*CampaignApi* | [**put_api202301_external_campaign_by_campaign_id**](docs/CampaignApi.md#put_api202301_external_campaign_by_campaign_id) | **PUT** /2025-04/retail-media/campaigns/{campaignId} | 
*CampaignApi* | [**put_api_v2_external_auction_line_item_by_line_item_id**](docs/CampaignApi.md#put_api_v2_external_auction_line_item_by_line_item_id) | **PUT** /2025-04/retail-media/auction-line-items/{line-item-id} | 
*CampaignApi* | [**put_api_v2_external_line_item_bid_multipliers_by_line_item_id**](docs/CampaignApi.md#put_api_v2_external_line_item_bid_multipliers_by_line_item_id) | **PUT** /2025-04/retail-media/line-items/{line-item-id}/bid-multipliers | 
*CampaignApi* | [**set_keyword_bids**](docs/CampaignApi.md#set_keyword_bids) | **POST** /2025-04/retail-media/line-items/{id}/keywords/set-bid | 
*CampaignApi* | [**unpause_promoted_products**](docs/CampaignApi.md#unpause_promoted_products) | **POST** /2025-04/retail-media/line-items/{line-item-id}/products/unpause | 
*CampaignApi* | [**update_campaign_budget_overrides**](docs/CampaignApi.md#update_campaign_budget_overrides) | **PUT** /2025-04/retail-media/campaigns/{campaignId}/campaign-budget-overrides | 
*CampaignApi* | [**update_line_item_budget_overrides**](docs/CampaignApi.md#update_line_item_budget_overrides) | **PUT** /2025-04/retail-media/line-items/{lineItemId}/line-item-budget-overrides | 
*GatewayApi* | [**get_current_application**](docs/GatewayApi.md#get_current_application) | **GET** /2025-04/retail-media/me | 


## Documentation For Models

 - [AddFundsToBalanceV2](docs/AddFundsToBalanceV2.md)
 - [AddFundsToBalanceV2Request](docs/AddFundsToBalanceV2Request.md)
 - [AddRemoveKeywordModel](docs/AddRemoveKeywordModel.md)
 - [AddRemoveKeywordsModel](docs/AddRemoveKeywordsModel.md)
 - [AddRemoveKeywordsModelRequest](docs/AddRemoveKeywordsModelRequest.md)
 - [AddRemoveKeywordsModelResource](docs/AddRemoveKeywordsModelResource.md)
 - [AddToBasketIdsUpdateModel202110Request](docs/AddToBasketIdsUpdateModel202110Request.md)
 - [AddToBasketTarget202110Request](docs/AddToBasketTarget202110Request.md)
 - [AddToBasketTarget202110Response](docs/AddToBasketTarget202110Response.md)
 - [ApplicationSummaryModel](docs/ApplicationSummaryModel.md)
 - [ApplicationSummaryModelResource](docs/ApplicationSummaryModelResource.md)
 - [ApplicationSummaryModelResponse](docs/ApplicationSummaryModelResponse.md)
 - [Asset](docs/Asset.md)
 - [AssetResource](docs/AssetResource.md)
 - [AssetResponse](docs/AssetResponse.md)
 - [AsyncCampaignsReport](docs/AsyncCampaignsReport.md)
 - [AsyncCampaignsReportRequest](docs/AsyncCampaignsReportRequest.md)
 - [AsyncCampaignsReportResource](docs/AsyncCampaignsReportResource.md)
 - [AsyncLineItemsReport](docs/AsyncLineItemsReport.md)
 - [AsyncLineItemsReportRequest](docs/AsyncLineItemsReportRequest.md)
 - [AsyncLineItemsReportResource](docs/AsyncLineItemsReportResource.md)
 - [AsyncReportResponse](docs/AsyncReportResponse.md)
 - [AsyncRevenueReport](docs/AsyncRevenueReport.md)
 - [AsyncRevenueReportRequest](docs/AsyncRevenueReportRequest.md)
 - [AsyncRevenueReportResource](docs/AsyncRevenueReportResource.md)
 - [AuctionLineItemCreateModelRequest](docs/AuctionLineItemCreateModelRequest.md)
 - [AuctionLineItemPagedListResponse](docs/AuctionLineItemPagedListResponse.md)
 - [AuctionLineItemResponse](docs/AuctionLineItemResponse.md)
 - [AuctionLineItemUpdateModelRequest](docs/AuctionLineItemUpdateModelRequest.md)
 - [AudienceError](docs/AudienceError.md)
 - [AudienceIdsUpdateModel202110Request](docs/AudienceIdsUpdateModel202110Request.md)
 - [AudienceTarget202110Request](docs/AudienceTarget202110Request.md)
 - [AudienceTarget202110Response](docs/AudienceTarget202110Response.md)
 - [AudienceWarning](docs/AudienceWarning.md)
 - [BalanceCampaign202110ListRequest](docs/BalanceCampaign202110ListRequest.md)
 - [BalanceCampaign202110PagedListResponse](docs/BalanceCampaign202110PagedListResponse.md)
 - [BalanceHistoryChangeDataCaptureV1](docs/BalanceHistoryChangeDataCaptureV1.md)
 - [BalanceResponseV2](docs/BalanceResponseV2.md)
 - [BalanceResponseV2Response](docs/BalanceResponseV2Response.md)
 - [CampaignAttributesV202301](docs/CampaignAttributesV202301.md)
 - [CampaignBudgetOverrides](docs/CampaignBudgetOverrides.md)
 - [CampaignDailyBudgetOverride](docs/CampaignDailyBudgetOverride.md)
 - [CampaignMonthlyBudgetOverride](docs/CampaignMonthlyBudgetOverride.md)
 - [CampaignV202301](docs/CampaignV202301.md)
 - [Category202204](docs/Category202204.md)
 - [Category202204ListResponse](docs/Category202204ListResponse.md)
 - [ChangeDatesOfBalanceV2](docs/ChangeDatesOfBalanceV2.md)
 - [ChangeDatesOfBalanceV2Request](docs/ChangeDatesOfBalanceV2Request.md)
 - [ChangeDetailsV1](docs/ChangeDetailsV1.md)
 - [ChoiceOption](docs/ChoiceOption.md)
 - [ChoiceVariableSpecification](docs/ChoiceVariableSpecification.md)
 - [ChoiceVariableValue](docs/ChoiceVariableValue.md)
 - [ColorVariableValue](docs/ColorVariableValue.md)
 - [CommonError](docs/CommonError.md)
 - [CommonLineItemPagedListResponse](docs/CommonLineItemPagedListResponse.md)
 - [CommonLineItemResponse](docs/CommonLineItemResponse.md)
 - [CommonProblem](docs/CommonProblem.md)
 - [CommonWarning](docs/CommonWarning.md)
 - [CpcMinBidsRequest](docs/CpcMinBidsRequest.md)
 - [CpcMinBidsResponse](docs/CpcMinBidsResponse.md)
 - [CreateBalanceV2](docs/CreateBalanceV2.md)
 - [CreateBalanceV2Request](docs/CreateBalanceV2Request.md)
 - [Creative2](docs/Creative2.md)
 - [Creative202110](docs/Creative202110.md)
 - [Creative202110ListResponse](docs/Creative202110ListResponse.md)
 - [Creative202210](docs/Creative202210.md)
 - [Creative202210Response](docs/Creative202210Response.md)
 - [Creative2ListResponse](docs/Creative2ListResponse.md)
 - [Creative2Response](docs/Creative2Response.md)
 - [CreativeCreateModel202207](docs/CreativeCreateModel202207.md)
 - [CreativeUpdateModel202207](docs/CreativeUpdateModel202207.md)
 - [DailyLineItemBudgetOverride](docs/DailyLineItemBudgetOverride.md)
 - [EditableCampaignAttributesV202301](docs/EditableCampaignAttributesV202301.md)
 - [EntityResourceCollectionOutcomeOfRetailMediaChildAccountAndMetadata](docs/EntityResourceCollectionOutcomeOfRetailMediaChildAccountAndMetadata.md)
 - [EntityResourceOfRetailMediaAccount](docs/EntityResourceOfRetailMediaAccount.md)
 - [EntityResourceOfRetailMediaChildAccount](docs/EntityResourceOfRetailMediaChildAccount.md)
 - [EntityResourceOutcomeOfRetailMediaAccount](docs/EntityResourceOutcomeOfRetailMediaAccount.md)
 - [ErrorCodeResponse](docs/ErrorCodeResponse.md)
 - [ExternalAccount](docs/ExternalAccount.md)
 - [ExternalAddToBasketIdsUpdateModel202110](docs/ExternalAddToBasketIdsUpdateModel202110.md)
 - [ExternalAddToBasketTarget202110](docs/ExternalAddToBasketTarget202110.md)
 - [ExternalAuctionLineItem](docs/ExternalAuctionLineItem.md)
 - [ExternalAuctionLineItemCreateModel](docs/ExternalAuctionLineItemCreateModel.md)
 - [ExternalAuctionLineItemUpdateModel](docs/ExternalAuctionLineItemUpdateModel.md)
 - [ExternalAudienceIdsUpdateModel202110](docs/ExternalAudienceIdsUpdateModel202110.md)
 - [ExternalAudienceTarget202110](docs/ExternalAudienceTarget202110.md)
 - [ExternalBrand](docs/ExternalBrand.md)
 - [ExternalCatalogRequest](docs/ExternalCatalogRequest.md)
 - [ExternalCatalogStatus](docs/ExternalCatalogStatus.md)
 - [ExternalCommonLineItem](docs/ExternalCommonLineItem.md)
 - [ExternalLineItemBidMultipliersV2](docs/ExternalLineItemBidMultipliersV2.md)
 - [ExternalLineItemCappingV2](docs/ExternalLineItemCappingV2.md)
 - [ExternalLineItemPageCategoryV2](docs/ExternalLineItemPageCategoryV2.md)
 - [ExternalLineItemPageV2](docs/ExternalLineItemPageV2.md)
 - [ExternalPreferredLineItemCreateModelV2](docs/ExternalPreferredLineItemCreateModelV2.md)
 - [ExternalPreferredLineItemUpdateModelV2](docs/ExternalPreferredLineItemUpdateModelV2.md)
 - [ExternalPreferredLineItemV2](docs/ExternalPreferredLineItemV2.md)
 - [ExternalRetailMediaAccount](docs/ExternalRetailMediaAccount.md)
 - [ExternalRetailMediaBrandAccountCreation](docs/ExternalRetailMediaBrandAccountCreation.md)
 - [ExternalRetailMediaBrands](docs/ExternalRetailMediaBrands.md)
 - [ExternalRetailMediaChildAccount](docs/ExternalRetailMediaChildAccount.md)
 - [ExternalRetailMediaSeller](docs/ExternalRetailMediaSeller.md)
 - [ExternalRetailMediaSellerAccountCreation](docs/ExternalRetailMediaSellerAccountCreation.md)
 - [ExternalRetailer](docs/ExternalRetailer.md)
 - [ExternalRetailerPages202110](docs/ExternalRetailerPages202110.md)
 - [ExternalStoreIdsUpdateModel202110](docs/ExternalStoreIdsUpdateModel202110.md)
 - [ExternalStoreTarget202110](docs/ExternalStoreTarget202110.md)
 - [FilesVariableValue](docs/FilesVariableValue.md)
 - [FilesVariablesSpecification](docs/FilesVariablesSpecification.md)
 - [GrantConsentInput](docs/GrantConsentInput.md)
 - [GrantConsentModel](docs/GrantConsentModel.md)
 - [GrantConsentModelValueResource](docs/GrantConsentModelValueResource.md)
 - [HyperlinkVariableValue](docs/HyperlinkVariableValue.md)
 - [InputKeywords](docs/InputKeywords.md)
 - [InputKeywordsModel](docs/InputKeywordsModel.md)
 - [InputResourceOfAuctionLineItemCreateModel](docs/InputResourceOfAuctionLineItemCreateModel.md)
 - [InputResourceOfPreferredLineItemCreateModelV2](docs/InputResourceOfPreferredLineItemCreateModelV2.md)
 - [JsonApiBodyWithExternalIdOfEditableCampaignAttributesV202301AndCampaignV202301](docs/JsonApiBodyWithExternalIdOfEditableCampaignAttributesV202301AndCampaignV202301.md)
 - [JsonApiBodyWithIdOfInt64AndAccountAndAccount](docs/JsonApiBodyWithIdOfInt64AndAccountAndAccount.md)
 - [JsonApiBodyWithIdOfInt64AndBrandAndBrand](docs/JsonApiBodyWithIdOfInt64AndBrandAndBrand.md)
 - [JsonApiBodyWithIdOfInt64AndCampaignV202301AndCampaignV202301](docs/JsonApiBodyWithIdOfInt64AndCampaignV202301AndCampaignV202301.md)
 - [JsonApiBodyWithIdOfInt64AndCatalogStatusAndCatalogStatus](docs/JsonApiBodyWithIdOfInt64AndCatalogStatusAndCatalogStatus.md)
 - [JsonApiBodyWithIdOfInt64AndLineItemBidMultipliersV2AndLineItemBidMultipliersV2](docs/JsonApiBodyWithIdOfInt64AndLineItemBidMultipliersV2AndLineItemBidMultipliersV2.md)
 - [JsonApiBodyWithIdOfInt64AndRetailerAndRetailer](docs/JsonApiBodyWithIdOfInt64AndRetailerAndRetailer.md)
 - [JsonApiBodyWithoutIdOfCampaignAttributesV202301AndCampaignV202301](docs/JsonApiBodyWithoutIdOfCampaignAttributesV202301AndCampaignV202301.md)
 - [JsonApiBodyWithoutIdOfCatalogRequestAndCatalogRequest](docs/JsonApiBodyWithoutIdOfCatalogRequestAndCatalogRequest.md)
 - [JsonApiBodyWithoutIdOfSellerCatalogRequestAndSellerCatalogRequest](docs/JsonApiBodyWithoutIdOfSellerCatalogRequestAndSellerCatalogRequest.md)
 - [JsonApiPageResponseOfAccount](docs/JsonApiPageResponseOfAccount.md)
 - [JsonApiPageResponseOfBrand](docs/JsonApiPageResponseOfBrand.md)
 - [JsonApiPageResponseOfCampaignV202301](docs/JsonApiPageResponseOfCampaignV202301.md)
 - [JsonApiPageResponseOfRetailer](docs/JsonApiPageResponseOfRetailer.md)
 - [JsonApiRequestOfCatalogRequest](docs/JsonApiRequestOfCatalogRequest.md)
 - [JsonApiRequestOfSellerCatalogRequest](docs/JsonApiRequestOfSellerCatalogRequest.md)
 - [JsonApiSingleResponseOfCampaignV202301](docs/JsonApiSingleResponseOfCampaignV202301.md)
 - [JsonApiSingleResponseOfCatalogStatus](docs/JsonApiSingleResponseOfCatalogStatus.md)
 - [JsonApiSingleResponseOfLineItemBidMultipliersV2](docs/JsonApiSingleResponseOfLineItemBidMultipliersV2.md)
 - [KeywordDataModel](docs/KeywordDataModel.md)
 - [Keywords](docs/Keywords.md)
 - [KeywordsModel](docs/KeywordsModel.md)
 - [KeywordsModelResource](docs/KeywordsModelResource.md)
 - [KeywordsModelResponse](docs/KeywordsModelResponse.md)
 - [LineItemBidMultipliersV2Request](docs/LineItemBidMultipliersV2Request.md)
 - [LineItemBidMultipliersV2Response](docs/LineItemBidMultipliersV2Response.md)
 - [LineItemBudgetOverrides](docs/LineItemBudgetOverrides.md)
 - [LineItemProductStatus](docs/LineItemProductStatus.md)
 - [MatchTypeModel](docs/MatchTypeModel.md)
 - [Metadata](docs/Metadata.md)
 - [MonthlyLineItemBudegetOverride](docs/MonthlyLineItemBudegetOverride.md)
 - [NillableDecimal](docs/NillableDecimal.md)
 - [NillableString](docs/NillableString.md)
 - [Outcome](docs/Outcome.md)
 - [PageMetadata](docs/PageMetadata.md)
 - [PageOfBalanceHistoryChangeDataCaptureV1](docs/PageOfBalanceHistoryChangeDataCaptureV1.md)
 - [PageTypeEnvironment2](docs/PageTypeEnvironment2.md)
 - [PageTypeEnvironment202210](docs/PageTypeEnvironment202210.md)
 - [PagedResourceCollectionOutcomeOfBalanceResponseV2](docs/PagedResourceCollectionOutcomeOfBalanceResponseV2.md)
 - [PostCampaignV202301](docs/PostCampaignV202301.md)
 - [PreferredLineItemCreateModelV2Request](docs/PreferredLineItemCreateModelV2Request.md)
 - [PreferredLineItemUpdateModelV2Request](docs/PreferredLineItemUpdateModelV2Request.md)
 - [PreferredLineItemV2PagedListResponse](docs/PreferredLineItemV2PagedListResponse.md)
 - [PreferredLineItemV2Response](docs/PreferredLineItemV2Response.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [ProductMetadata](docs/ProductMetadata.md)
 - [ProductResourceOutcome](docs/ProductResourceOutcome.md)
 - [PromotedProduct](docs/PromotedProduct.md)
 - [PromotedProductResource](docs/PromotedProductResource.md)
 - [PromotedProductResourceCollectionInput](docs/PromotedProductResourceCollectionInput.md)
 - [PromotedProductResourceCollectionOutcome](docs/PromotedProductResourceCollectionOutcome.md)
 - [PutCampaignV202301](docs/PutCampaignV202301.md)
 - [RecommendedKeywordsResult](docs/RecommendedKeywordsResult.md)
 - [ReportOutcome](docs/ReportOutcome.md)
 - [ResourceOfAddFundsToBalanceV2](docs/ResourceOfAddFundsToBalanceV2.md)
 - [ResourceOfAuctionLineItem](docs/ResourceOfAuctionLineItem.md)
 - [ResourceOfAuctionLineItemUpdateModel](docs/ResourceOfAuctionLineItemUpdateModel.md)
 - [ResourceOfBalanceCampaign202110](docs/ResourceOfBalanceCampaign202110.md)
 - [ResourceOfBalanceResponseV2](docs/ResourceOfBalanceResponseV2.md)
 - [ResourceOfCategory202204](docs/ResourceOfCategory202204.md)
 - [ResourceOfChangeDatesOfBalanceV2](docs/ResourceOfChangeDatesOfBalanceV2.md)
 - [ResourceOfCommonLineItem](docs/ResourceOfCommonLineItem.md)
 - [ResourceOfCreateBalanceV2](docs/ResourceOfCreateBalanceV2.md)
 - [ResourceOfCreative2](docs/ResourceOfCreative2.md)
 - [ResourceOfCreative202110](docs/ResourceOfCreative202110.md)
 - [ResourceOfCreative202210](docs/ResourceOfCreative202210.md)
 - [ResourceOfLineItemBidMultipliersV2](docs/ResourceOfLineItemBidMultipliersV2.md)
 - [ResourceOfPreferredLineItemUpdateModelV2](docs/ResourceOfPreferredLineItemUpdateModelV2.md)
 - [ResourceOfPreferredLineItemV2](docs/ResourceOfPreferredLineItemV2.md)
 - [ResourceOfTemplate](docs/ResourceOfTemplate.md)
 - [ResourceOfUpdateBalanceModelV2](docs/ResourceOfUpdateBalanceModelV2.md)
 - [ResourceOutcome](docs/ResourceOutcome.md)
 - [RetailMediaContactlistAmendment](docs/RetailMediaContactlistAmendment.md)
 - [RetailMediaContactlistAmendmentAttributes](docs/RetailMediaContactlistAmendmentAttributes.md)
 - [RetailMediaContactlistAmendmentRequest](docs/RetailMediaContactlistAmendmentRequest.md)
 - [RetailMediaContactlistOperation](docs/RetailMediaContactlistOperation.md)
 - [RetailMediaContactlistOperationResponseAttributes](docs/RetailMediaContactlistOperationResponseAttributes.md)
 - [RetailMediaSeller](docs/RetailMediaSeller.md)
 - [ReviewStateModel](docs/ReviewStateModel.md)
 - [RmAlgebraNodeV1](docs/RmAlgebraNodeV1.md)
 - [RmAudienceEntityV1](docs/RmAudienceEntityV1.md)
 - [RmAudienceEntityV1Resource](docs/RmAudienceEntityV1Resource.md)
 - [RmAudienceEntityV1RmAudienceSearchMetadataV1ListResponse](docs/RmAudienceEntityV1RmAudienceSearchMetadataV1ListResponse.md)
 - [RmAudienceSearchEntityV1](docs/RmAudienceSearchEntityV1.md)
 - [RmAudienceSearchEntityV1Resource](docs/RmAudienceSearchEntityV1Resource.md)
 - [RmAudienceSearchInputV1](docs/RmAudienceSearchInputV1.md)
 - [RmAudienceSearchMetadataV1](docs/RmAudienceSearchMetadataV1.md)
 - [RmAudienceSegmentBulkCreateInputV1](docs/RmAudienceSegmentBulkCreateInputV1.md)
 - [RmAudienceSegmentBulkDeleteInputV1](docs/RmAudienceSegmentBulkDeleteInputV1.md)
 - [RmAudienceSegmentBulkUpdateInputV1](docs/RmAudienceSegmentBulkUpdateInputV1.md)
 - [RmAudienceSegmentCreateEntityV1](docs/RmAudienceSegmentCreateEntityV1.md)
 - [RmAudienceSegmentCreateEntityV1Resource](docs/RmAudienceSegmentCreateEntityV1Resource.md)
 - [RmAudienceSegmentDeleteEntityV1Resource](docs/RmAudienceSegmentDeleteEntityV1Resource.md)
 - [RmAudienceSegmentEntityV1](docs/RmAudienceSegmentEntityV1.md)
 - [RmAudienceSegmentEntityV1ListResponse](docs/RmAudienceSegmentEntityV1ListResponse.md)
 - [RmAudienceSegmentEntityV1Resource](docs/RmAudienceSegmentEntityV1Resource.md)
 - [RmAudienceSegmentEntityV1RmAudienceSegmentSearchMetadataV1ListResponse](docs/RmAudienceSegmentEntityV1RmAudienceSegmentSearchMetadataV1ListResponse.md)
 - [RmAudienceSegmentIdEntityV1ListResponse](docs/RmAudienceSegmentIdEntityV1ListResponse.md)
 - [RmAudienceSegmentIdEntityV1Resource](docs/RmAudienceSegmentIdEntityV1Resource.md)
 - [RmAudienceSegmentSearchEntityV1](docs/RmAudienceSegmentSearchEntityV1.md)
 - [RmAudienceSegmentSearchEntityV1Resource](docs/RmAudienceSegmentSearchEntityV1Resource.md)
 - [RmAudienceSegmentSearchInputV1](docs/RmAudienceSegmentSearchInputV1.md)
 - [RmAudienceSegmentSearchMetadataV1](docs/RmAudienceSegmentSearchMetadataV1.md)
 - [RmAudienceSegmentUpdateEntityV1](docs/RmAudienceSegmentUpdateEntityV1.md)
 - [RmAudienceSegmentUpdateEntityV1Resource](docs/RmAudienceSegmentUpdateEntityV1Resource.md)
 - [RmContactListCreateV1](docs/RmContactListCreateV1.md)
 - [RmContactListStatisticsEntityV1](docs/RmContactListStatisticsEntityV1.md)
 - [RmContactListStatisticsEntityV1Resource](docs/RmContactListStatisticsEntityV1Resource.md)
 - [RmContactListStatisticsEntityV1Response](docs/RmContactListStatisticsEntityV1Response.md)
 - [RmContactListV1](docs/RmContactListV1.md)
 - [RmEventsCreateV1](docs/RmEventsCreateV1.md)
 - [RmEventsUpdateV1](docs/RmEventsUpdateV1.md)
 - [RmEventsV1](docs/RmEventsV1.md)
 - [RmcaCommonProblem](docs/RmcaCommonProblem.md)
 - [SdkApiRestCommonProblem](docs/SdkApiRestCommonProblem.md)
 - [Section](docs/Section.md)
 - [SellerCatalogRequest](docs/SellerCatalogRequest.md)
 - [SellerIdentifier](docs/SellerIdentifier.md)
 - [SellerSearch](docs/SellerSearch.md)
 - [SellerSearchResult](docs/SellerSearchResult.md)
 - [SetBidModel](docs/SetBidModel.md)
 - [SetBidsModel](docs/SetBidsModel.md)
 - [SetBidsModelRequest](docs/SetBidsModelRequest.md)
 - [SetBidsModelResource](docs/SetBidsModelResource.md)
 - [SkuMinBid](docs/SkuMinBid.md)
 - [StatusResponse](docs/StatusResponse.md)
 - [StatusResponseResource](docs/StatusResponseResource.md)
 - [StoreIdsUpdateModel202110Request](docs/StoreIdsUpdateModel202110Request.md)
 - [StoreTarget202110Request](docs/StoreTarget202110Request.md)
 - [StoreTarget202110Response](docs/StoreTarget202110Response.md)
 - [Template](docs/Template.md)
 - [TemplateListResponse](docs/TemplateListResponse.md)
 - [TemplateResponse](docs/TemplateResponse.md)
 - [TemplateVariable](docs/TemplateVariable.md)
 - [TemplateVariableValue](docs/TemplateVariableValue.md)
 - [TextVariableSpecification](docs/TextVariableSpecification.md)
 - [TextVariableValue](docs/TextVariableValue.md)
 - [UpdateBalanceModelV2](docs/UpdateBalanceModelV2.md)
 - [UpdateBalanceModelV2Request](docs/UpdateBalanceModelV2Request.md)
 - [ValueResourceCollectionInputOfRetailMediaSeller](docs/ValueResourceCollectionInputOfRetailMediaSeller.md)
 - [ValueResourceCollectionOutcomeOfRetailMediaSeller](docs/ValueResourceCollectionOutcomeOfRetailMediaSeller.md)
 - [ValueResourceCollectionOutcomeOfSellerSearchResult](docs/ValueResourceCollectionOutcomeOfSellerSearchResult.md)
 - [ValueResourceCpcMinBidsRequest](docs/ValueResourceCpcMinBidsRequest.md)
 - [ValueResourceCpcMinBidsResponse](docs/ValueResourceCpcMinBidsResponse.md)
 - [ValueResourceInputCpcMinBidsRequest](docs/ValueResourceInputCpcMinBidsRequest.md)
 - [ValueResourceInputOfCampaignBudgetOverrides](docs/ValueResourceInputOfCampaignBudgetOverrides.md)
 - [ValueResourceInputOfLineItemBudgetOverrides](docs/ValueResourceInputOfLineItemBudgetOverrides.md)
 - [ValueResourceInputOfRetailMediaBrandAccountCreation](docs/ValueResourceInputOfRetailMediaBrandAccountCreation.md)
 - [ValueResourceInputOfRetailMediaBrands](docs/ValueResourceInputOfRetailMediaBrands.md)
 - [ValueResourceInputOfRetailMediaSellerAccountCreation](docs/ValueResourceInputOfRetailMediaSellerAccountCreation.md)
 - [ValueResourceInputOfSellerSearch](docs/ValueResourceInputOfSellerSearch.md)
 - [ValueResourceOfCampaignBudgetOverrides](docs/ValueResourceOfCampaignBudgetOverrides.md)
 - [ValueResourceOfLineItemBudgetOverrides](docs/ValueResourceOfLineItemBudgetOverrides.md)
 - [ValueResourceOfRecommendedKeywordsResult](docs/ValueResourceOfRecommendedKeywordsResult.md)
 - [ValueResourceOfRetailMediaBrandAccountCreation](docs/ValueResourceOfRetailMediaBrandAccountCreation.md)
 - [ValueResourceOfRetailMediaBrands](docs/ValueResourceOfRetailMediaBrands.md)
 - [ValueResourceOfRetailMediaSeller](docs/ValueResourceOfRetailMediaSeller.md)
 - [ValueResourceOfRetailMediaSellerAccountCreation](docs/ValueResourceOfRetailMediaSellerAccountCreation.md)
 - [ValueResourceOfSellerSearch](docs/ValueResourceOfSellerSearch.md)
 - [ValueResourceOfSellerSearchResult](docs/ValueResourceOfSellerSearchResult.md)
 - [ValueResourceOutcomeCpcMinBidsResponse](docs/ValueResourceOutcomeCpcMinBidsResponse.md)
 - [ValueResourceOutcomeOfCampaignBudgetOverrides](docs/ValueResourceOutcomeOfCampaignBudgetOverrides.md)
 - [ValueResourceOutcomeOfLineItemBudgetOverrides](docs/ValueResourceOutcomeOfLineItemBudgetOverrides.md)
 - [ValueResourceOutcomeOfRecommendedKeywordsResult](docs/ValueResourceOutcomeOfRecommendedKeywordsResult.md)
 - [ValueResourceOutcomeOfRetailMediaBrands](docs/ValueResourceOutcomeOfRetailMediaBrands.md)
 - [ValueTypeResourceOfAddToBasketIdsUpdateModel202110](docs/ValueTypeResourceOfAddToBasketIdsUpdateModel202110.md)
 - [ValueTypeResourceOfAddToBasketTarget202110](docs/ValueTypeResourceOfAddToBasketTarget202110.md)
 - [ValueTypeResourceOfAudienceIdsUpdateModel202110](docs/ValueTypeResourceOfAudienceIdsUpdateModel202110.md)
 - [ValueTypeResourceOfAudienceTarget202110](docs/ValueTypeResourceOfAudienceTarget202110.md)
 - [ValueTypeResourceOfStoreIdsUpdateModel202110](docs/ValueTypeResourceOfStoreIdsUpdateModel202110.md)
 - [ValueTypeResourceOfStoreTarget202110](docs/ValueTypeResourceOfStoreTarget202110.md)
 - [VideoVariableValue](docs/VideoVariableValue.md)


## Disclaimer

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.